<?php
if(!defined('ABSPATH')){ exit; }

use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Image_Size;
use Elementor\Repeater;

class GVAElement_Contact_Support extends GVAElement_Base{
   const NAME = 'gva-contact-support';
   const TEMPLATE = 'general/contact-support';
   const CATEGORY = 'aports_general';

   public function get_name() {
      return self::NAME;
   }

   public function get_categories() {
      return array(self::CATEGORY);
   }

   public function get_title() {
      return esc_html__('Contact Support', 'aports-themer');
   }

   public function get_keywords() {
      return [ 'contact', 'support', 'form', 'content' ];
   }

   public function get_script_depends() {
      return [
         'gavias.elements',
      ];
   }

   public function get_style_depends() {
      return array();
   }

   protected function register_controls() {
      $forms = array();
      $posts = get_posts(array(
        'post_type'     => 'wpcf7_contact_form',
        'numberposts'   => -1
      ));
      foreach($posts as $p){
         $forms[$p->ID] =  $p->post_title;
      }

      $this->start_controls_section(
         'section_content',
         [
            'label' => esc_html__('Content', 'aports-themer'),
         ]
      );
      $this->add_control(
         'style',
         [
            'label'        => esc_html__('Style', 'aports-themer'),
            'type'         => Controls_Manager::SELECT,
            'options' => [
               'style-1'   => esc_html__('Style 01', 'aports-themer'),
            ],
            'default' => 'style-1',
         ]
      );
      $this->add_control(
         'sub_title',
         [
            'label'        => __( 'Sub Title', 'aports-themer' ),
            'type'         => Controls_Manager::TEXT,
            'placeholder'  => __( 'Enter your Sub Title', 'aports-themer' ),
            'default'      => __('Free quote', 'aports-themer'),
            'label_block'  => true,
         ]
      );
      $this->add_control(
         'title_text',
         [
            'label'        => __( 'Title', 'aports-themer' ),
            'type'         => Controls_Manager::TEXTAREA,
            'placeholder'  => __( 'Enter your title', 'aports-themer' ),
            'default'      => __( 'Get an insurance quote to get started', 'aports-themer' ),
            'label_block'  => true,
         ]
      );
      $this->add_control(
         'form_id',
         [
            'label'       => esc_html__('Contact Form', 'aports-themer'),
            'type'        => Controls_Manager::SELECT,
            'options'     => $forms
         ]
      );
      $this->add_control(
         'image',
         [
            'label'        => __( 'Choose Image', 'aports-themer' ),
            'type'         => Controls_Manager::MEDIA,
            'label_block'  => true,
            'default' => [
               'url' => GAVIAS_APORTS_PLUGIN_URL . 'elementor/assets/images/image-7.png',
            ],
         ]
      );

      $this->add_control(
         'heading_agent',
         [
            'label'       => esc_html__('Agent Information --------', 'aports-themer'),
            'type'        => Controls_Manager::HEADING
         ]
      );
      $this->add_control(
         'agent_image',
         [
            'label'        => __( 'Choose Image', 'aports-themer' ),
            'type'         => Controls_Manager::MEDIA,
            'label_block'  => true,
            'default' => [
               'url' => GAVIAS_APORTS_PLUGIN_URL . 'elementor/assets/images/team-2.jpg',
            ],
         ]
      );
      $this->add_control(
         'agent_title',
         [
            'label'        => __( 'Agent Title', 'aports-themer' ),
            'type'         => Controls_Manager::TEXT,
            'placeholder'  => __( 'Enter your title', 'aports-themer' ),
            'default'      => __( 'Contact Agent', 'aports-themer' ),
            'label_block'  => true,
         ]
      );
      $this->add_control(
         'agent_name',
         [
            'label'        => __( 'Agent Name', 'aports-themer' ),
            'type'         => Controls_Manager::TEXT,
            'placeholder'  => __( 'Enter your title', 'aports-themer' ),
            'default'      => __( 'William Jacobs', 'aports-themer' ),
            'label_block'  => true,
         ]
      );
      $this->add_control(
         'agent_desc',
         [
            'label'        => __( 'Agent Description', 'aports-themer' ),
            'type'         => Controls_Manager::TEXT,
            'placeholder'  => __( 'Enter your description', 'aports-themer' ),
            'default'      => __( 'Certified Agent', 'aports-themer' ),
            'label_block'  => true,
         ]
      );
      $this->add_control(
         'agent_phone',
         [
            'label'        => __( 'Agent Phone', 'aports-themer' ),
            'type'         => Controls_Manager::TEXT,
            'placeholder'  => __( 'Enter your phone', 'aports-themer' ),
            'default'      => __( '012-888-2222', 'aports-themer' ),
            'label_block'  => true,
         ]
      );
      $this->add_control(
         'agent_email',
         [
            'label'        => __( 'Agent Email', 'aports-themer' ),
            'type'         => Controls_Manager::TEXT,
            'placeholder'  => __( 'Enter your email', 'aports-themer' ),
            'default'      => __( 'contact@example.com', 'aports-themer' ),
            'label_block'  => true,
         ]
      );
      $this->add_control(
         'facebook',
         [
            'label'      => __('Agent Facebook', 'aports-themer'),
            'type'       => Controls_Manager::URL,
         ]
      );

      $this->add_control(
         'twitter',
         [
            'label'      => __('Agent Twitter', 'aports-themer'),
            'type'       => Controls_Manager::URL,
         ]
      );
      $this->add_control(
         'instagram',
         [
            'label'      => __('Agent Instagram', 'aports-themer'),
            'type'       => Controls_Manager::URL,
         ]
      );
      $this->add_control(
         'pinterest',
         [
            'label'      => __('Agent Pinterest', 'aports-themer'),
            'type'       => Controls_Manager::URL,
         ]
      );
      $this->end_controls_section();

      // === Style Tabs ==================
      $this->start_controls_section(
         'section_style_tab',
         [
            'label' => __( 'Style', 'aports-themer' ),
            'tab'   => Controls_Manager::TAB_STYLE,
         ]
      );
      $this->end_controls_section();

   }

   protected function render() {
      $settings = $this->get_settings_for_display();
      printf('<div class="gva-element-%s gva-element">', $this->get_name() );
      include $this->get_template(self::TEMPLATE . '.php');
      print '</div>';
   }

}

$widgets_manager->register(new GVAElement_Contact_Support());
