<?php
if(!defined('ABSPATH')){ exit; }

use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Image_Size;
use Elementor\Repeater;

class GVAElement_Neighborhoods extends GVAElement_Base{
  	const NAME = 'gva-neighborhoods';
  	const TEMPLATE = 'general/neighborhoods/';
  	const CATEGORY = 'aports_general';

  	public function get_name() {
	 	return self::NAME;
  	}

  	public function get_categories() {
	 	return array(self::CATEGORY);
  	}

	public function get_title() {
		return esc_html__('Neighborhoods', 'aports-themer');
	}

	public function get_keywords() {
		return [ 'neighborhoods', 'content' ];
	}

	public function get_script_depends() {
		return [
			'gavias.elements',
		];
	}

	public function get_style_depends() {
		return array();
	}

	protected function register_controls() {
		$this->start_controls_section(
			'section_content',
			[
				'label' => esc_html__('Content', 'aports-themer'),
			]
		);
		$this->add_control( // xx Layout
			'layout_heading',
			[
				'label'   => esc_html__('Layout', 'aports-themer'),
				'type'    => Controls_Manager::HEADING,
			]
		);
		$this->add_control(
			'title_text',
			[
				'label'       => esc_html__('Title', 'aports-themer'),
				'type'        => Controls_Manager::TEXT,
				'default'     => 'Add your Title',
				'label_block' => true,
			]
		);
		$this->add_control(
			'layout',
			[
				'label'   => esc_html__('Layout Display', 'aports-themer'),
				'type'    => Controls_Manager::SELECT,
				'default' => 'layout-1',
				'options' => [
					'layout-1'      => esc_html__('Layout 01', 'aports-themer'),
					'layout-2'  => esc_html__('Layout 02', 'aports-themer')
				]
			]
	  	);
	  	$this->add_control(
			'image',
			[
				'label'      => esc_html__('Choose Image', 'aports-themer'),
				'default'    => [
					'url' => GAVIAS_APORTS_PLUGIN_URL . 'elementor/assets/images/neighborhoods.jpg',
				],
				'type'       => Controls_Manager::MEDIA,
				'show_label' => false,
			]
		);
		$repeater = new Repeater();
		$repeater->add_control(
			'title',
			[
				'label'       => esc_html__('Title', 'aports-themer'),
				'type'        => Controls_Manager::TEXT,
				'default'     => 'Add your Title',
				'label_block' => true,
			]
		);
		$repeater->add_control(
			'desc',
			[
				'label'       => esc_html__('Description', 'aports-themer'),
				'type'        => Controls_Manager::TEXTAREA,
				'default'     => 'Metropolitan Opera House Lincoln Center Theater New York.',
				'label_block' => true,
			]
		);
		$repeater->add_control(
			'content',
			[
				'label'       => esc_html__('Content', 'aports-themer'),
				'type'        => Controls_Manager::TEXTAREA,
				'default'     => 'Lorem ipsum dolor sit amet, consecte adipiscing elit, sed do eiusmod tempor inci simply free.',
				'label_block' => true,
			]
		);
		$repeater->add_control(
			'selected_icon',
			[
				'label'      => esc_html__('Choose Icon', 'aports-themer'),
				'type'       => Controls_Manager::ICONS
			]
		);
		$repeater->add_control(
			'left',
			[
				'label'     	=> esc_html__('Left', 'aports-themer'),
				'type'      	=> Controls_Manager::SLIDER,
				'size_units' 	=> '%',
				'range' => [
					'%' => [
						'min' => 0,
						'max' => 100,
					],
				],
				'default' => [
					'unit' => '%',
					'size' => 10,
				],
				'selectors' => [
					'{{WRAPPER}} {{CURRENT_ITEM}}' => 'left: {{SIZE}}{{UNIT}};',
				]
			]
		);
		$repeater->add_control(
			'top',
			[
				'label'     => esc_html__('Top', 'aports-themer'),
				'type'      => Controls_Manager::SLIDER,
				'size_units' 	=> '%',
				'range' => [
					'%' => [
						'min' => 0,
						'max' => 100,
					],
				],
				'default' => [
					'unit' => '%',
					'size' => 10,
				],
				'selectors' => [
					'{{WRAPPER}} {{CURRENT_ITEM}}' => 'top: {{SIZE}}{{UNIT}};',
				]
			]
		);
		$repeater->add_control(
			'distance',
			[
				'label'     	=> esc_html__('Distance', 'aports-themer'),
				'type'      	=> Controls_Manager::TEXT,
				'placeholder' 	=> esc_html__('Distance', 'aports-themer'),
				'default'		=> '13.5KM'
			]
		);
		$this->add_control(
			'neighborhoods_content',
			[
				'label'       => esc_html__('Service Content Item', 'aports-themer'),
				'type'        => Controls_Manager::REPEATER,
				'fields'      => $repeater->get_controls(),
				'title_field' => '{{{ title }}}',
				'default'     => array(
				  	array(
					 	'title'  => esc_html__('Restaurants', 'aports-themer'),
					 	'left'	=> array('unit' => '%','size' => 10),
					 	'right'	=> array('unit' => '%','size' => 10),
				  	),
				  	array(
					 	'title'  => esc_html__('Central park', 'aports-themer'),
				  	),
				  	array(
					 	'title'  => esc_html__('Shopping center', 'aports-themer'),
				  	),
				  	array(
					 	'title'  => esc_html__('Hospitals', 'aports-themer'),
				  	),
				  	array(
					 	'title'  => esc_html__('Play grounds', 'aports-themer')
				  	)
				)
			]
		);

		$this->end_controls_section();

		// Icon Styling
		$this->start_controls_section(
			'section_style',
			[
				'label' => esc_html__('Style', 'aports-themer'),
				'tab'   => Controls_Manager::TAB_STYLE,
			]
		);

		$this->end_controls_section();

	}

	protected function render() {
		$settings = $this->get_settings_for_display();
		printf('<div class="gva-element-%s gva-element">', $this->get_name() );
		if( !empty($settings['layout']) ){
			include $this->get_template(self::TEMPLATE . $settings['layout'] . '.php');
		}
		print '</div>';
	}
}

$widgets_manager->register(new GVAElement_Neighborhoods());
